==> extension_qt-6.8.2.tar.xz: extension_qt-6.8.2/config.sh <==
echo "# $EXTENSION/build_order.txt" 				 	 > $EXTENSION/build_order.txt
echo "# <scriptname> (without .sh)" 					>> $EXTENSION/build_order.txt
echo "" 												>> $EXTENSION/build_order.txt

source /etc/profile

# Required
[ ! -f /etc/extension/extension_xorg_libraries ] && echo "Installing xorg_libraries" && extension --install xorg_libraries && echo "Finished xorg_libraries"
[[ ! -f /etc/profile.d/xorg.sh ]] && echo "Installing xorg_build_env" && extension --install xorg_build_env && echo "Finished xorg_build_env"
source /etc/profile.d/xorg.sh
# Recommended
if [[ $INSTALL_RECOMMENDED != false ]]; then 
	[[ $(command -v aserver) == "" ]] && echo "Installing alsa_lib" && extension --install alsa_lib && echo "Finished alsa_lib"
	[[ $(command -v make-ca) == "" ]] && echo "Installing make_ca" && extension --install make_ca && echo "Finished make_ca"
	[[ $(command -v cupsd) == "" ]] && echo "Installing cups" && extension --install cups && echo "Finished cups"
	[ ! -f /lib/libdouble-conversion.so ] && echo "Installing double_conversion" && extension --install double_conversion && echo "Finished double_conversion"
	[[ $(command -v gdbus) == "" ]] && echo "Installing glib" && extension --install glib && echo "Finished glib"
	[[ $(command -v gst-play-1.0) == "" ]] && echo "Installing gst_plugins_base" && extension --install gst_plugins_base && echo "Finished gst_plugins_base"
	[[ $(command -v hb-info) == "" ]] && echo "Installing harfbuzz" && extension --install harfbuzz && echo "Finished harfbuzz"
	[[ $(command -v derb) == "" ]] && echo "Installing icu" && extension --install icu && echo "Finished icu"
	[[ $(command -v jasper) == "" ]] && echo "Installing jasper" && extension --install jasper && echo "Finished jasper"
	[[ $(command -v cjpeg) == "" ]] && echo "Installing libjpeg-turbo" && extension --install libjpeg_turbo && echo "Finished libjpeg_turbo"
	[[ $(command -v libinput) == "" ]] && echo "Installing libinput" && extension --install libinput && echo "Finished libinput"
	[ ! -f /lib/libmng.so ] && echo "Installing libmng" && extension --install libmng && echo "Finished libmng"
	[[ $(command -v pngfix) == "" ]] && echo "Installing libpng" && extension --install libpng && echo "Finished libpng"
	[[ $(command -v tiffinfo) == "" ]] && echo "Installing libtiff" && extension --install libtiff && echo "Finished libtiff"
	[[ $(command -v webpinfo) == "" ]] && echo "Installing libwebp" && extension --install libwebp && echo "Finished libwebp"
	[[ $(command -v xkbcli) == "" ]] && echo "Installing libxkbcommon" && extension --install libxkbcommon && echo "Finished libxkbcommon"
	[[ $(command -v glxinfo) == "" ]] && echo "Installing mesa" && extension --install mesa && echo "Finished mesa"
	[[ $(command -v mtdev-test) == "" ]] && echo "Installing mtdev" && extension --install mtdev && echo "Finished mtdev"
	[[ $(command -v pcre2test) == "" ]] && echo "Installing pcre2" && extension --install pcre2 && echo "Finished pcre2"
	[[ $(command -v sqlite3) == "" ]] && echo "Installing sqlite" && extension --install sqlite && echo "Finished sqlite"
	[[ $(command -v wayland-scanner) == "" ]] && echo "Installing wayland" && extension --install wayland && echo "Finished wayland"
	[ ! -f /etc/extension/extension_xcb_utilities ] && echo "Installing xcb_utilities" && extension --install xcb_utilities && echo "Finished xcb_utilities"
	# Recommended
	[[ $(command -v btmon) == "" ]] && echo "Installing bluez" && extension --install bluez && echo "Finished bluez"
	[[ $(command -v gtk-launch) == "" ]] && echo "Installing gtk3" && extension --install gtk3 && echo "Finished gtk3"
	#[[ $(command -v ibus-daemon) == "" ]] && echo "Installing ibus" && extension --install ibus && echo "Finished ibus"
	[[ $(command -v clang) == "" ]] && echo "Installing llvm" && extension --install llvm && echo "Finished llvm"
	#[[ $(command -v mariadb) == "" ]] && echo "Installing mariadb" && extension --install mariadb && echo "Finished mariadb"
	#[[ $(command -v krb5-config) == "" ]] && echo "Installing mit_kerberos_v5" && extension --install mit_kerberos_v5 && echo "Finished mit_kerberos_v5"
	#[[ $(command -v pciutils) == "" ]] && echo "Installing pciutils" && extension --install pciutils && echo "Finished pciutils"
	#[[ $(command -v psql) == "" ]] && echo "Installing postgresql" && extension --install postgresql && echo "Finished postgresql"
	[[ $(command -v pulseaudio) == "" ]] && echo "Installing pulseaudio" && extension --install pulseaudio && echo "Finished pulseaudio"
	[[ $(command -v sdl2-config) == "" ]] && echo "Installing sdl2" && extension --install sdl2 && echo "Finished sdl2"
	#[[ $(command -v odbcinst) == "" ]] && echo "Installing unixodbc" && extension --install unixodbc && echo "Finished unixodbc"
	[[ $(command -v ffmpeg) == "" ]] && echo "Installing ffmpeg" && extension --install ffmpeg && echo "Finished ffmpeg"
fi

if [ $BUILD_ALL == "false" ] && [[ $(command -v designer) == "" ]]; then
	echo "qt" 											>> $EXTENSION/build_order.txt
fi
if [ $BUILD_ALL == "true" ]; then
	echo "qt" 											>> $EXTENSION/build_order.txt
fi
echo "complete _" 										>> $EXTENSION/build_order.txt

==> extension_qt-6.9.1.tar.xz: extension_qt-6.9.1/config.sh <==
echo "# $EXTENSION/build_order.txt" 				 	 > $EXTENSION/build_order.txt
echo "# <scriptname> (without .sh)" 					>> $EXTENSION/build_order.txt
echo "" 												>> $EXTENSION/build_order.txt

source /etc/profile

# Required
[ ! -f /etc/extension/extension_xorg_libraries ] && echo "Installing xorg_libraries" && extension --install xorg_libraries && echo "Finished xorg_libraries"
[ ! -f /etc/profile.d/xorg.sh ] && echo "Installing xorg_build_env" && extension --install xorg_build_env && echo "Finished xorg_build_env"
source /etc/profile.d/xorg.sh
[ ! -f /lib/libX11.so ] && echo "Installing xorg_libraries" && extension --install xorg_libraries --rebuild && echo "Finished xorg_libraries"
[ ! -f /lib/libSM.so ] && echo "Installing xorg_libraries" && extension --install xorg_libraries --rebuild && echo "Finished xorg_libraries"
[ ! -f /lib/libxcb-image.so ] && echo "Installing xcb_utilities" && extension --install xcb_utilities --rebuild && echo "Finished xcb_utilities"
[ ! -f /lib/libxcb-render-util.so ] && echo "Installing xcb_utilities" && extension --install xcb_utilities --rebuild && echo "Finished xcb_utilities"
[ ! -f /lib/libxcb-ewmh.so ] && echo "Installing xcb_utilities" && extension --install xcb_utilities --rebuild && echo "Finished xcb_utilities"
[ ! -f /lib/libxcb-icccm.so ] && echo "Installing xcb_utilities" && extension --install xcb_utilities --rebuild && echo "Finished xcb_utilities"
[ ! -f /lib/libxcb-cursor.so ] && echo "Installing xcb_utilities" && extension --install xcb_utilities --rebuild && echo "Finished xcb_utilities"
[ ! -f /lib/libxcb-util.so ] && echo "Installing xcb_util" && extension --install xcb_util --rebuild && echo "Finished xcb_util"
[ ! -f /lib/libxcb.so ] && echo "Installing libxcb" && extension --install libxcb --rebuild && echo "Finished libxcb"
# Recommended
if [[ $INSTALL_RECOMMENDED != false ]]; then 
	[[ $(command -v aserver) == "" ]] && echo "Installing alsa_lib" && extension --install alsa_lib && echo "Finished alsa_lib"
	[[ $(command -v make-ca) == "" ]] && echo "Installing make_ca" && extension --install make_ca && echo "Finished make_ca"
	[[ $(command -v cupsd) == "" ]] && echo "Installing cups" && extension --install cups && echo "Finished cups"
	[ ! -f /lib/libdouble-conversion.so ] && echo "Installing double_conversion" && extension --install double_conversion && echo "Finished double_conversion"
	[[ $(command -v gdbus) == "" ]] && echo "Installing glib" && extension --install glib && echo "Finished glib"
	[[ $(command -v gst-play-1.0) == "" ]] && echo "Installing gst_plugins_base" && extension --install gst_plugins_base && echo "Finished gst_plugins_base"
	[[ $(command -v hb-info) == "" ]] && echo "Installing harfbuzz" && extension --install harfbuzz && echo "Finished harfbuzz"
	[[ $(command -v derb) == "" ]] && echo "Installing icu" && extension --install icu && echo "Finished icu"
	[[ $(command -v jasper) == "" ]] && echo "Installing jasper" && extension --install jasper && echo "Finished jasper"
	[[ $(command -v cjpeg) == "" ]] && echo "Installing libjpeg-turbo" && extension --install libjpeg_turbo && echo "Finished libjpeg_turbo"
	[[ $(command -v libinput) == "" ]] && echo "Installing libinput" && extension --install libinput && echo "Finished libinput"
	[ ! -f /lib/libmng.so ] && echo "Installing libmng" && extension --install libmng && echo "Finished libmng"
	[[ $(command -v pngfix) == "" ]] && echo "Installing libpng" && extension --install libpng && echo "Finished libpng"
	[[ $(command -v tiffinfo) == "" ]] && echo "Installing libtiff" && extension --install libtiff && echo "Finished libtiff"
	[[ $(command -v webpinfo) == "" ]] && echo "Installing libwebp" && extension --install libwebp && echo "Finished libwebp"
	[[ $(command -v xkbcli) == "" ]] && echo "Installing libxkbcommon" && extension --install libxkbcommon && echo "Finished libxkbcommon"
	[[ $(command -v glxinfo) == "" ]] && echo "Installing mesa" && extension --install mesa && echo "Finished mesa"
	[[ $(command -v mtdev-test) == "" ]] && echo "Installing mtdev" && extension --install mtdev && echo "Finished mtdev"
	[[ $(command -v pcre2test) == "" ]] && echo "Installing pcre2" && extension --install pcre2 && echo "Finished pcre2"
	[[ $(command -v sqlite3) == "" ]] && echo "Installing sqlite" && extension --install sqlite && echo "Finished sqlite"
	[[ $(command -v wayland-scanner) == "" ]] && echo "Installing wayland" && extension --install wayland && echo "Finished wayland"
	[ ! -f /etc/extension/extension_xcb_utilities ] && echo "Installing xcb_utilities" && extension --install xcb_utilities && echo "Finished xcb_utilities"
fi
# Optional
if [[ $INSTALL_OPTIONAL != false ]]; then 
	[[ $(command -v btmon) == "" ]] && echo "Installing bluez" && extension --install bluez && echo "Finished bluez"
	[[ $(command -v gtk-launch) == "" ]] && echo "Installing gtk3" && extension --install gtk3 && echo "Finished gtk3"
	#[[ $(command -v ibus-daemon) == "" ]] && echo "Installing ibus" && extension --install ibus && echo "Finished ibus"
	[[ $(command -v clang) == "" ]] && echo "Installing llvm" && extension --install llvm && echo "Finished llvm"
	#[[ $(command -v mariadb) == "" ]] && echo "Installing mariadb" && extension --install mariadb && echo "Finished mariadb"
	#[[ $(command -v krb5-config) == "" ]] && echo "Installing mit_kerberos_v5" && extension --install mit_kerberos_v5 && echo "Finished mit_kerberos_v5"
	[[ $(command -v lspci) == "" ]] && echo "Installing pciutils" && extension --install pciutils && echo "Finished pciutils"
	#[[ $(command -v psql) == "" ]] && echo "Installing postgresql" && extension --install postgresql && echo "Finished postgresql"
	[[ $(command -v pulseaudio) == "" ]] && echo "Installing pulseaudio" && extension --install pulseaudio && echo "Finished pulseaudio"
	[[ $(command -v sdl2-config) == "" ]] && echo "Installing sdl2" && extension --install sdl2 && echo "Finished sdl2"
	[[ $(command -v odbcinst) == "" ]] && echo "Installing unixodbc" && extension --install unixodbc && echo "Finished unixodbc"
	[[ $(command -v ffmpeg) == "" ]] && echo "Installing ffmpeg" && extension --install ffmpeg && echo "Finished ffmpeg"

	[[ $(command -v protoc) == "" ]] && echo "Installing protobuf" && extension --install protobuf && echo "Finished protobuf"
fi

if [ $BUILD_ALL == "false" ] && [[ $(command -v designer) == "" ]]; then
	echo "qt" 											>> $EXTENSION/build_order.txt
fi
if [ $BUILD_ALL == "true" ]; then
	echo "qt" 											>> $EXTENSION/build_order.txt
fi
echo "complete _" 										>> $EXTENSION/build_order.txt
